pub struct CommitFact {
pub project_id: String,
pub parents: Vec<String>,
pub id: CommitFactId,
}Expand description
Commit-graph slice: sha -> parent shas. id = commit sha (hex) — content addressed and immutable (a sha’s parents never change), so publication is idempotent. Lets git-free nodes (the hub) resolve ancestry.
Fields
project_id: Stringparents: Vec<String>id: CommitFactIdTrait Implementations
Sourceimpl AnyItem for CommitFact
impl AnyItem for CommitFact
Sourcefn entity_type(&self) -> &'static str
fn entity_type(&self) -> &'static str
Returns the entity type name (e.g., “Target”, “Scene”).
Sourcefn server_owner(&self) -> Option<&str>
fn server_owner(&self) -> Option<&str>
Returns the current
#[server_owned] field value, if this item has one.Sourceimpl Clone for CommitFact
impl Clone for CommitFact
Sourcefn clone(&self) -> CommitFact
fn clone(&self) -> CommitFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommitFact
impl Debug for CommitFact
Sourceimpl<'de> Deserialize<'de> for CommitFact
impl<'de> Deserialize<'de> for CommitFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Eventable for CommitFact
impl Eventable for CommitFact
Sourceconst ENTITY_NAME_STATIC: &'static str = "CommitFact"
const ENTITY_NAME_STATIC: &'static str = "CommitFact"
Static entity type name (use
entity_type() from AnyItem for instance access).Sourcefn entity_name_static() -> &'static str
fn entity_name_static() -> &'static str
Back-compat helper for generic call sites that still expect a function.
Sourcefn ingest_buffer_policy() -> IngestBufferPolicy
fn ingest_buffer_policy() -> IngestBufferPolicy
Opt-in ingest buffering policy for this entity type.
Sourceimpl IdFor<CommitFact> for CommitFactId
impl IdFor<CommitFact> for CommitFactId
Sourceimpl Partial for CommitFact
impl Partial for CommitFact
Sourcetype Item = PartialCommitFact
type Item = PartialCommitFact
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreSourceimpl PartialEq for CommitFact
impl PartialEq for CommitFact
Sourceimpl Serialize for CommitFact
impl Serialize for CommitFact
impl StructuralPartialEq for CommitFact
Sourceimpl WithTypedId for CommitFact
impl WithTypedId for CommitFact