pub struct Project {
pub name: String,
pub created: String,
pub id: ProjectId,
}Expand description
Project identity, minted by levi init. id = project UUID (32 hex chars),
stored in the first event on the ref.
Fields
name: Stringcreated: StringRFC3339
id: ProjectIdTrait Implementations
Sourceimpl AnyItem for Project
impl AnyItem for Project
Sourcefn entity_type(&self) -> &'static str
fn entity_type(&self) -> &'static str
Returns the entity type name (e.g., “Target”, “Scene”).
Sourcefn server_owner(&self) -> Option<&str>
fn server_owner(&self) -> Option<&str>
Returns the current
#[server_owned] field value, if this item has one.Sourceimpl<'de> Deserialize<'de> for Project
impl<'de> Deserialize<'de> for Project
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Eventable for Project
impl Eventable for Project
Sourceconst ENTITY_NAME_STATIC: &'static str = "Project"
const ENTITY_NAME_STATIC: &'static str = "Project"
Static entity type name (use
entity_type() from AnyItem for instance access).Sourcefn entity_name_static() -> &'static str
fn entity_name_static() -> &'static str
Back-compat helper for generic call sites that still expect a function.
Sourcefn ingest_buffer_policy() -> IngestBufferPolicy
fn ingest_buffer_policy() -> IngestBufferPolicy
Opt-in ingest buffering policy for this entity type.
Sourceimpl Partial for Project
impl Partial for Project
Sourcetype Item = PartialProject
type Item = PartialProject
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreimpl StructuralPartialEq for Project