pub struct RefFact {
pub project_id: String,
pub branch: String,
pub head: String,
pub observed: String,
pub id: RefFactId,
}Expand description
Observed branch head. id = “{project_id}:{branch}” — LWW: the newest observation wins.
Fields
project_id: Stringbranch: Stringhead: StringHead commit sha (hex).
observed: StringRFC3339
id: RefFactIdTrait Implementations
Sourceimpl AnyItem for RefFact
impl AnyItem for RefFact
Sourcefn entity_type(&self) -> &'static str
fn entity_type(&self) -> &'static str
Returns the entity type name (e.g., “Target”, “Scene”).
Sourcefn server_owner(&self) -> Option<&str>
fn server_owner(&self) -> Option<&str>
Returns the current
#[server_owned] field value, if this item has one.Sourceimpl<'de> Deserialize<'de> for RefFact
impl<'de> Deserialize<'de> for RefFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Eventable for RefFact
impl Eventable for RefFact
Sourceconst ENTITY_NAME_STATIC: &'static str = "RefFact"
const ENTITY_NAME_STATIC: &'static str = "RefFact"
Static entity type name (use
entity_type() from AnyItem for instance access).Sourcefn entity_name_static() -> &'static str
fn entity_name_static() -> &'static str
Back-compat helper for generic call sites that still expect a function.
Sourcefn ingest_buffer_policy() -> IngestBufferPolicy
fn ingest_buffer_policy() -> IngestBufferPolicy
Opt-in ingest buffering policy for this entity type.
Sourceimpl Partial for RefFact
impl Partial for RefFact
Sourcetype Item = PartialRefFact
type Item = PartialRefFact
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreimpl StructuralPartialEq for RefFact