pub enum Resolution {
Exact,
Facts,
Partial,
}Variants
Exact
Ancestry answered by the real repo (gix merge-base).
Facts
Ancestry answered by walking the CommitFact graph.
Partial
At least one relevant anchor could not be resolved; unknown changes were treated as open and the task should be flagged.
Implementations