pub fn link()Expand description
Binaries that receive levi entities over the wire (the hub) must call this: without any referenced symbol from this crate, the linker drops its object files — including the inventory registrations for entities, commands, and sagas.